summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
Diffstat (limited to 'src/include')
-rw-r--r--src/include/usr/sbeio/sbe_psudd.H14
-rw-r--r--src/include/usr/sbeio/sbeioif.H14
-rw-r--r--src/include/usr/sbeio/sbeioreasoncodes.H2
3 files changed, 17 insertions, 13 deletions
diff --git a/src/include/usr/sbeio/sbe_psudd.H b/src/include/usr/sbeio/sbe_psudd.H
index c16a3baa2..2ad545f5f 100644
--- a/src/include/usr/sbeio/sbe_psudd.H
+++ b/src/include/usr/sbeio/sbe_psudd.H
@@ -440,19 +440,21 @@ class SbePsu
};
/**
- * @Brief perform SBE PSU chip-op
+ * @brief perform SBE PSU chip-op
*
+ * @param[in] i_target Proc target to use for PSU Request
* @param[in] i_pPsuRequest Pointer to PSU request commands
* @param[out] o_pPsuResponse Pointer to PSU response
* @param[in] i_timeout Time out for response
* @param[in] i_reqMsgs 4 bit mask telling which regs to write
* @param[in] i_rspMsgs 4 bit mask telling which regs to read
*/
- errlHndl_t performPsuChipOp(psuCommand * i_pPsuCommand,
- psuResponse * o_pPsuResponse,
- const uint64_t i_timeout,
- uint8_t i_reqMsgs,
- uint8_t i_rspMsgs);
+ errlHndl_t performPsuChipOp(TARGETING::Target * i_target,
+ psuCommand * i_pPsuRequest,
+ psuResponse * o_pPsuResponse,
+ const uint64_t i_timeout,
+ uint8_t i_reqMsgs,
+ uint8_t i_rspMsgs);
protected:
diff --git a/src/include/usr/sbeio/sbeioreasoncodes.H b/src/include/usr/sbeio/sbeioreasoncodes.H
index abd9540ca..7294a45c3 100644
--- a/src/include/usr/sbeio/sbeioreasoncodes.H
+++ b/src/include/usr/sbeio/sbeioreasoncodes.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2013,2016 */
+/* Contributors Listed Below - COPYRIGHT 2013,2017 */
/* [+] International Business Machines Corp. */
/* */
/* */
OpenPOWER on IntegriCloud
diff --git a/src/include/usr/sbeio/sbeioif.H b/src/include/usr/sbeio/sbeioif.H
index 0a94caae3..3c014df48 100644
--- a/src/include/usr/sbeio/sbeioif.H
+++ b/src/include/usr/sbeio/sbeioif.H
@@ -62,12 +62,14 @@ namespace SBEIO
errlHndl_t sendSystemConfig(const uint64_t i_systemConfig );
/**
- * @brief Sends a PSU chipOp to quiesce the SBE
- *
- * @return errlHndl_t Error log handle on failure.
- *
- */
- errlHndl_t sendPsuQueisceSbeCmd ();
+ * @brief Sends a PSU chipOp to quiesce the SBE
+ *
+ * @param[in] i_target Target with SBE to quiesce
+ *
+ * @return errlHndl_t Error log handle on failure.
+ *
+ */
+ errlHndl_t sendPsuQuiesceSbe(TARGETING::Target * i_target);
/**
* @brief Get SCOM via SBE FIFO